aboutsummaryrefslogtreecommitdiff
path: root/ssl/error.rs
diff options
context:
space:
mode:
authorSteven Fackler <[email protected]>2014-02-04 18:42:32 -0800
committerSteven Fackler <[email protected]>2014-02-04 18:42:32 -0800
commit1a5e625b4f21c9b4870ef30ab1da3c1fed919672 (patch)
treed646e51e83df4c33cad2dba6fafce9a43fdd5366 /ssl/error.rs
parentRemove unused FFI binding (diff)
downloadrust-openssl-1a5e625b4f21c9b4870ef30ab1da3c1fed919672.tar.xz
rust-openssl-1a5e625b4f21c9b4870ef30ab1da3c1fed919672.zip
Update for IO API update
The error handling needs to be redone still.
Diffstat (limited to 'ssl/error.rs')
-rw-r--r--ssl/error.rs7
1 files changed, 4 insertions, 3 deletions
diff --git a/ssl/error.rs b/ssl/error.rs
index 769cc768..91e879c8 100644
--- a/ssl/error.rs
+++ b/ssl/error.rs
@@ -1,12 +1,13 @@
use std::libc::c_ulong;
+use std::io::IoError;
-use super::ffi;
+use ssl::ffi;
/// An SSL error
#[deriving(ToStr)]
pub enum SslError {
- /// The underlying stream has reported an EOF
- StreamEof,
+ /// The underlying stream has reported an error
+ StreamError(IoError),
/// The SSL session has been closed by the other end
SslSessionClosed,
/// An error in the OpenSSL library